@@ -2,11 +2,11 @@ package PICA::Data;
 use strict;
 use warnings;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 use Exporter 'import';
-our @EXPORT_OK = map { "pica_$_" } 
-                 qw(parser writer values value fields holdings items path);
+our @EXPORT_OK = qw(pica_parser pica_writer pica_path pica_xml_struct
+    pica_values pica_value pica_fields pica_holdings pica_items);
 our %EXPORT_TAGS = (all => [@EXPORT_OK]); 
 
 our $ILN_PATH = PICA::Path->new('101@a');
@@ -166,6 +166,24 @@ sub _pica_module {
     }
 }
 
+sub pica_xml_struct {
+    my ($xml, %options) = @_;
+    my $record;
+
+    foreach my $f (@{$xml->[2]}) {
+        next unless $f->[0] eq 'datafield';
+        push @$record, [
+            map ( { $f->[1]->{$_} } qw(tag occurrence) ),
+            map ( { $_->[1]->{code} => $_->[2]->[0] } @{$f->[2]} )
+        ]
+    }
+
+    my ($id) = map { $_->[-1] } grep { $_->[0] =~ '003@' } @$record;
+    $record = { _id => $id, record => $record };
+    bless $record, 'PICA::Data' if !!$options{bless};
+    return $record;
+}
+
 1;
 __END__
 
@@ -193,10 +211,20 @@ PICA::Data - PICA record processing
     $writer = PICA::Writer::Plain->new( @options );
 
     while ( my $record = $parser->next ) {
-        my $ppn      = pica_value($record, '003@0'); # == $record->{_id}
+        
+        # function accessors
+        my $ppn      = pica_value($record, '003@0');
         my $holdings = pica_holdings($record);
-        my $items    = pica_holdings($record);
+        my $items    = pica_items($record);
         ...
+
+        # object accessors (if parser option 'bless' enabled)
+        my $ppn      = $record->{_id};
+        my $ppn      = $record->value('003@0');
+        my $holdings = $record->holdings;
+        my $items    = $record->items;
+        ...
+
     }
   
     # parse single record from string
@@ -231,14 +259,18 @@ or in short form:
 
     [ [ '003@', undef, '0' => '12345X' ] ]
 
-PICA path expressions can be used to facilitate processing PICA+ records.
+PICA path expressions (see L<PICA::Path>) can be used to facilitate processing
+PICA+ records.
 
-=head1 CONSTRUCTORS
+=head1 FUNCTIONS
+
+The following functions can be exported on request (use export tag C<:all> to
+get all of them):
 
 =head2 pica_parser( $type [, @options] )
 
 Create a PICA parsers object. Case of the type is ignored and additional
-parameters are passed to the parser's constructor.
+parameters are passed to the parser's constructor:
 
 =over
 
@@ -266,7 +298,6 @@ Create a PICA writer object in the same way as C<pica_parser> with one of
 
 L<PICA::Writer::XML> for type C<xml> or C<picaxml> (PICA-XML)
 
-
 =item 
 
 L<PICA::Writer::Plus> for type C<plus> or C<picaplus> (normalized PICA+)
@@ -279,40 +310,48 @@ L<PICA::Writer::Plain> for type C<plain> or C<picaplain> (human-readable PICA+)
 
 =head2 pica_path( $path )
 
-Equivalent to C<< PICA::Path->new($path) >>.
+Equivalent to L<<PICA::Path->new($path)|PICA::Path>>.
+
+=head2 pica_values( $record, $path )
+
+=head2 pica_value( $record, $path )
+
+=head2 pica_fields( $record, $path )
+
+=head2 pica_holdings( $record )
+
+=head2 pica_head2s( $record )
+
+=head2 pica_xml_struct( $xml, %options )
+
+Convert PICA-XML, expressed in L<XML::Struct> structure into an (optionally
+blessed) PICA record structure.
 
 =head1 ACCESSORS
 
-The following function can also be called as method on a blessed PICA::Data
-record by stripping the C<pica_...> prefix:
+All accessors of C<PICA::Data> are also available as L</FUNCTIONS>, prefixed
+with C<pica_> (see L</SYNOPSIS>).
 
-    bless $record, 'PICA::Data';
-    $record->values($path);
-    $record->items;
-    ...
-
-=head2 pica_values( $record, $path )
+=head2 values( $path )
 
 Extract a list of subfield values from a PICA record based on a PICA path
 expression.
 
-=head2 pica_value( $record, $path )
+=head2 value( $path )
 
-Same as C<pica_values> but only returns the first value. Can also be called as
-C<value> on a blessed PICA::Data record.
+Same as C<values> but only returns the first value.
 
-=head2 pica_fields( $record, $path )
+=head2 fields( $path )
 
 Returns a PICA record limited to fields specified in a PICA path expression.
-Always returns an array reference. Can also be called as C<fields> on a blessed
-PICA::Data record. 
+Always returns an array reference.
 
-=head2 pica_holdings( $record )
+=head2 holdings
 
 Returns a list (as array reference) of local holding records (level 1 and 2),
 where the C<_id> of each record contains the ILN (subfield C<101@a>).
 
-=head2 pica_items( $record )
+=head2 items
 
 Returns a list (as array reference) of item records (level 1),
 where the C<_id> of each record contains the EPN (subfield C<203@/**0>).
@@ -323,23 +362,29 @@ Johann Rolschewski, C<< <rolschewski@gmail.com> >>
 
 Jakob Voss C<< <voss@gbv.de> >>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
 Copyright 2014- Johann Rolschewski and Jakob Voss
 
-=head1 LICENSE
-
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
 =head1 SEE ALSO
 
+=over
+
+=item
+
+L<PICA::Record> (deprecated) implemented an alternative framework for
+processing PICA+ records.
+
+=item 
+
 Use L<Catmandu::PICA> for processing PICA records with the L<Catmandu> toolkit,
 for instance to convert PICA XML to plain PICA+:
 
    catmandu convert PICA --type xml to PICA --type plain < picadata.xml
 
-L<PICA::Record> implements an alternative framework for processing PICA+
-records but development of the module is stalled.
+=back
 
 =cut
