@@ -2,7 +2,7 @@ package PICA::Parser::Plain;
 use strict;
 use warnings;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 use charnames qw(:full);
 use constant SUBFIELD_INDICATOR => '$';
@@ -11,7 +11,7 @@ use constant END_OF_RECORD      => "\N{LINE FEED}";
 
 use Carp qw(croak);
 
-use parent 'PICA::Parser::Plus';
+use parent 'PICA::Parser::Base';
 
 sub next_record {
     my ($self) = @_;
